summaryrefslogtreecommitdiff
path: root/solenv
diff options
context:
space:
mode:
authorMatúš Kukan <matus.kukan@gmail.com>2013-04-15 14:42:09 +0200
committerMatúš Kukan <matus.kukan@gmail.com>2013-04-15 14:42:09 +0200
commita90616b8c0f007e0329b0cc8353e8029e4993f79 (patch)
tree0c1bbfcca582883f35c8028d7415a46bbffeaf19 /solenv
parent3df1af355d8aa133cd983f15b17c740a1e9a85f7 (diff)
installer: gid_File_Lib_Vcl is now auto_File_Lib_vcl
Change-Id: Ib8508ad50b8f2b4ce0443be0b1437c2595b9b6d5
Diffstat (limited to 'solenv')
-rw-r--r--solenv/bin/modules/installer/profiles.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/solenv/bin/modules/installer/profiles.pm b/solenv/bin/modules/installer/profiles.pm
index 3b99973a92a4..b83b69653dfd 100644
--- a/solenv/bin/modules/installer/profiles.pm
+++ b/solenv/bin/modules/installer/profiles.pm
@@ -84,9 +84,9 @@ sub add_profile_into_filelist
my %profile = ();
- # Taking the base data from the "gid_File_Lib_Vcl"
+ # Taking the base data from the "auto_File_Lib_vcl"
- my $vclgid = "gid_File_Lib_Vcl";
+ my $vclgid = "auto_File_Lib_vcl";
if ( $allvariables->{'GLOBALFILEGID'} ) { $vclgid = $allvariables->{'GLOBALFILEGID'}; }
my ($vclfile) = grep {$_->{gid} eq $vclgid} @{$filesarrayref};
if (! defined $vclfile) {